@@ -915,7 +915,9 @@ impl<'a> FnAnalyzer<'a> {
                     params = params.into_iter().skip(1).collect();
                     param_details.remove(0);
                     MethodKind::MakeUnique
-                } else if let Some(constructor_suffix) = rust_name.strip_prefix(nested_type_ident) {
+                } else if let Some(constructor_suffix) =
+                    constructor_with_suffix(&rust_name, nested_type_ident)
+                {
                     // It's a constructor. bindgen generates
                     // fn Type(this: *mut Type, ...args)
                     // We want
@@ -1024,6 +1026,9 @@ impl<'a> FnAnalyzer<'a> {
                 if param_details.len() < 2 {
                     set_ignore_reason(ConvertError::ConstructorWithOnlyOneParam);
                 }
+                if param_details.len() > 2 {
+                    set_ignore_reason(ConvertError::ConstructorWithMultipleParams);
+                }
                 self.reanalyze_parameter(
                     0,
                     fun,
@@ -1044,6 +1049,9 @@ impl<'a> FnAnalyzer<'a> {
                 if param_details.len() < 2 {
                     set_ignore_reason(ConvertError::ConstructorWithOnlyOneParam);
                 }
+                if param_details.len() > 2 {
+                    set_ignore_reason(ConvertError::ConstructorWithMultipleParams);
+                }
                 self.reanalyze_parameter(
                     0,
                     fun,
@@ -1603,12 +1611,15 @@ impl<'a> FnAnalyzer<'a> {
                                     };
                                     Ok((this_type, receiver_mutability))
                                 }
-                                _ => Err(ConvertError::UnexpectedThisType(
-                                    ns.clone(),
-                                    fn_name.into(),
-                                )),
+                                _ => Err(ConvertError::UnexpectedThisType(QualifiedName::new(
+                                    ns,
+                                    make_ident(fn_name),
+                                ))),
                             },
-                            _ => Err(ConvertError::UnexpectedThisType(ns.clone(), fn_name.into())),
+                            _ => Err(ConvertError::UnexpectedThisType(QualifiedName::new(
+                                ns,
+                                make_ident(fn_name),
+                            ))),
                         }?;
                         self_type = Some(this_type);
                         if treat_this_as_reference {
@@ -1959,6 +1970,19 @@ impl<'a> FnAnalyzer<'a> {
     }
 }
 
+/// Attempts to determine whether this function name is a constructor, and if so,
+/// returns the suffix.
+fn constructor_with_suffix<'a>(rust_name: &'a str, nested_type_ident: &str) -> Option<&'a str> {
+    let suffix = rust_name.strip_prefix(nested_type_ident);
+    suffix.and_then(|suffix| {
+        if suffix.is_empty() || suffix.parse::<u32>().is_ok() {
+            Some(suffix)
+        } else {
+            None
+        }
+    })
+}
+
 fn error_context_for_method(self_ty: &QualifiedName, rust_name: &str) -> ErrorContext {
     ErrorContext::new_for_method(self_ty.get_final_ident(), make_ident(rust_name))
 }
