@@ -188,6 +188,17 @@ impl<'a> TypeConverter<'a> {
             Type::Ptr(ptr) if ctx.convert_ptrs_to_references() => {
                 self.convert_ptr_to_reference(ptr, ns)?
             }
+            Type::Array(mut arr) => {
+                let innerty =
+                    self.convert_type(*arr.elem, ns, &TypeConversionContext::CxxInnerType)?;
+                arr.elem = Box::new(innerty.ty);
+                Annotated::new(
+                    Type::Array(arr),
+                    innerty.types_encountered,
+                    innerty.extra_apis,
+                    TypeKind::Regular,
+                )
+            }
             Type::Ptr(mut ptr) => {
                 crate::known_types::ensure_pointee_is_valid(&ptr)?;
                 let innerty =
